@@ -2,7 +2,7 @@ plot.confLCCR <-
 function(x,...){
 
   mlk = min(x$lkv)
-  plot(x$Nv,x$lkv,type="l",xlab="N",ylab="LogLk",col=4)
+  plot(x$Nv,x$lkv,type="l",xlab=expression(italic(N)),ylab="LogLik",col=4)
   lines(c(x$conf[1],x$conf[1]),c(mlk,x$lk1),col=2)
   lines(c(x$conf[2],x$conf[2]),c(mlk,x$lk2),col=2)
   lines(c(x$conf),c(x$lk1,x$lk2),col=2)
