@@ -1,7 +1,9 @@
 summary.confLCCR <-
 function(object, ...){
 
-  cat("\nConfidence interval for the populations size based on latent class models for capture recapture data\n")
+  cat("\nConfidence interval for the populations size based on latent class models")
+  cat("\nfor capture recapture data\n")
+  cat("\n")
   cat("Call:\n")
   print(object$call)
   cat("\nAvailable objects:\n")
